@@ -1,10 +1,9 @@
 <?php
+include_once(SM_PATH.'functions/mailbox_display.php');
 include_once(SM_PATH.'plugins/bayesspam/config.php');
 
 function bayesspam_filter($args) {
-   bayesspam_prune($args);
-
-   if (!isset($GLOBALS['bayesspam_filtering_enabled']) || !$GLOBALS['bayesspam_filtering_enabled'])
+   if (!$GLOBALS['bayesspam_filtering_enabled'])
       return 0;
 
    if($args[0] == 'left_main_before') {
@@ -12,21 +11,26 @@ function bayesspam_filter($args) {
    } else {
       bayesspam_filters($GLOBALS['imapConnection'], 1);
    }
-   return 1;
 }
 
-function bayesspam_filters($imap_stream, $use_mailbox=0) {
+function bayesspam_filters(&$imap_stream, $use_mailbox=0) {
+   $version_array = split('\.', $GLOBALS['version']);
+
+   $new_spam_occurences = array();
+   $new_nonspam_occurences = array();
    $spam_stats = 0;
    $ham_stats = 0;
    $unsure_stats = 0;
    $total_messages = 0;
+
    $run_folders = array();
    $boxes = sqimap_mailbox_list($imap_stream);
+   $sid = sqimap_session_id();
 
    foreach ($boxes as $box) {
-      if ($GLOBALS['bayesspam_inboxonly'] != 1 || ($GLOBALS['bayesspam_inboxonly'] == 1 && 'INBOX' ==  $box['unformatted-dm'])) {
+      if ($GLOBALS['bayesspam_inboxonly'] != 1 || ($GLOBALS['bayesspam_inboxonly'] == 1 && preg_match("/^INBOX$/", $box['unformatted-dm']))) {
          if (($use_mailbox == 1 && $box['unformatted-dm'] == $GLOBALS['mailbox'] && !in_array($box['unformatted-dm'],$GLOBALS['bayesspam_ignore_folders'])) || ($use_mailbox == 0 && !in_array($box['unformatted-dm'], $GLOBALS['bayesspam_ignore_folders']))) {
-            if ( (array_search('noselect', $box['flags']) === FALSE || array_search('noselect', $box['flags']) === NULL) && $GLOBALS['sent_folder'] != $box['unformatted-dm'] && sqimap_unseen_messages($imap_stream, $box['unformatted-dm']) > 0) {
+            if ( (array_search('noselect', $box['flags']) === FALSE || array_search('noselect', $box['flags']) === NULL) && !preg_match("/^INBOX\.Sent/", $box['unformatted-dm']) && sqimap_unseen_messages($imap_stream, $box['unformatted-dm']) > 0) {
                $run_folders[] = $box['unformatted-dm'];
             }
          }
@@ -41,11 +45,6 @@ function bayesspam_filters($imap_stream, $use_mailbox=0) {
 
       $messages = array();
       $search = "SEARCH UNSEEN UNDELETED";
-      if (isset($_SESSION['bayesspam_last_filter'])) {
-         $search .= " SINCE ".date('d-M-Y',$_SESSION['bayesspam_last_filter']);
-      }
-      $_SESSION['bayesspam_last_filter'] = time();      
-
       $read = sqimap_run_command($imap_stream, $search, TRUE, $response, $message, TRUE);
       if (isset($read[0])) {
          for ($i=0,$iCnt=count($read);$i<$iCnt;++$i) {
@@ -72,7 +71,7 @@ function bayesspam_filters($imap_stream, $use_mailbox=0) {
             $uncertain_messages[] = $passed_id;
          }
 
-         if ($GLOBALS['bayesspam_do_stats'] && $GLOBALS['bayesspam_do_user_stats'] && $bayesspam_old_message_score === FALSE) {
+         if ($bayesspam_old_message_score === FALSE && $GLOBALS['bayesspam_do_stats'] && $GLOBALS['bayesspam_do_user_stats']) {
             if ($is_spam > .9) {
                $spam_stats++;
                $total_messages++;
@@ -108,13 +107,29 @@ function bayesspam_filters($imap_stream, $use_mailbox=0) {
       }
    }
 
-   if ($GLOBALS['bayesspam_do_stats'] && $GLOBALS['bayesspam_do_user_stats'] && $total_messages) {
+   if ($GLOBALS['bayesspam_do_stats'] && $GLOBALS['bayesspam_do_user_stats']) {
       $res = $GLOBALS['bayesdbhandle']->query('SELECT UserName FROM '.$GLOBALS['bayesdbprefix'].'stats WHERE UserName=\''.$GLOBALS['bayes_username'].'\'');
 
+      if (DB::isError($res)) {
+         echo $res->getDebugInfo();
+      }
       if (!DB::isError($res) && !($row = $res->fetchRow())) {
-         $GLOBALS['bayesdbhandle']->query('INSERT INTO '.$GLOBALS['bayesdbprefix'].'stats SET StatsStart=NOW(),UserName=\''.$GLOBALS['bayes_username'].'\',TotalMessages='.$total_messages.',HamMessages='.$ham_stats.',SpamMessages='.$spam_stats.',UnsureMessages='.$unsure_stats.($GLOBALS['bayesspam_do_timing']?(',TimedMessages='.$GLOBALS['bayes_parsed_messages'].',TotalParseTime='.$GLOBALS['bayes_parse_time']):''));
-      } else {
-         $GLOBALS['bayesdbhandle']->query('UPDATE '.$GLOBALS['bayesdbprefix'].'stats SET TotalMessages=TotalMessages+'.$total_messages.',HamMessages=HamMessages+'.$ham_stats.',SpamMessages=SpamMessages+'.$spam_stats.', UnsureMessages=UnsureMessages+'.$unsure_stats.($GLOBALS['bayesspam_do_timing']?(',TimedMessages=TimedMessages+'.$GLOBALS['bayes_parsed_messages'].',TotalParseTime=TotalParseTime+'.$GLOBALS['bayes_parse_time']):'').' WHERE UserName=\''.$GLOBALS['bayes_username'].'\'');
+         $GLOBALS['bayesdbhandle']->query('INSERT INTO '.$GLOBALS['bayesdbprefix'].'stats SET StatsStart=NOW(),UserName=\''.$GLOBALS['bayes_username'].'\'');
+      } 
+
+      $GLOBALS['bayesdbhandle']->query('UPDATE '.$GLOBALS['bayesdbprefix'].'stats SET TotalMessages=TotalMessages+'.$total_messages.', HamMessages=HamMessages+'.$ham_stats.',SpamMessages=SpamMessages+'.$spam_stats.', UnsureMessages=UnsureMessages+'.$unsure_stats.' WHERE UserName=\''.$GLOBALS['bayes_username'].'\'');
+
+      if ($GLOBALS['bayesspam_do_timing']) {
+         $res = $GLOBALS['bayesdbhandle']->query('SELECT UserName FROM '.$GLOBALS['bayesdbprefix'].'stats WHERE UserName=\''.$GLOBALS['bayes_username'].'\'');
+   
+         if (DB::isError($res)) {
+            echo $res->getDebugInfo();
+         }
+         if (!DB::isError($res) && !($row = $res->fetchRow())) {
+            $GLOBALS['bayesdbhandle']->query('INSERT INTO '.$GLOBALS['bayesdbprefix'].'stats SET StatsStart=NOW(),UserName=\''.$GLOBALS['bayes_username'].'\'');
+         }
+   
+         $GLOBALS['bayesdbhandle']->query('UPDATE '.$GLOBALS['bayesdbprefix'].'stats SET TimedMessages=TimedMessages+'.$GLOBALS['bayes_parsed_messages'].',TotalParseTime=TotalParseTime+'.$GLOBALS['bayes_parse_time'].' WHERE UserName=\''.$GLOBALS['bayes_username'].'\'');
       }
    }
 }
